==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebNavDrawerHeaderItemDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebNavDrawerHeaderItemDescription } from "./WebNavDrawerHeaderItemDescription";
/**
 * @hidden
 */
export let WebNavDrawerHeaderItemDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebNavDrawerHeaderItemDescriptionMetadata extends Base {
        static b(a) {
            if (WebNavDrawerHeaderItemDescriptionMetadata.a == null) {
                WebNavDrawerHeaderItemDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebNavDrawerHeaderItemDescriptionMetadata.c(WebNavDrawerHeaderItemDescriptionMetadata.a);
            }
            if (a.k(WebNavDrawerHeaderItemDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebNavDrawerHeaderItemDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:NavDrawerHeaderItem");
            a.item("__tagNameWC", "String:igc-nav-drawer-header-item");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        }
        static d(a) {
            WebNavDrawerHeaderItemDescriptionMetadata.b(a);
            a.ac("WebNavDrawerHeaderItem", () => new WebNavDrawerHeaderItemDescription());
            a.ab("WebNavDrawerHeaderItem", WebNavDrawerHeaderItemDescriptionMetadata.a);
        }
    }
    WebNavDrawerHeaderItemDescriptionMetadata.$t = /*@__PURE__*/ markType(WebNavDrawerHeaderItemDescriptionMetadata, 'WebNavDrawerHeaderItemDescriptionMetadata');
    WebNavDrawerHeaderItemDescriptionMetadata.a = null;
    return WebNavDrawerHeaderItemDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/WebNavDrawerHeaderItemDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebNavDrawerHeaderItemDescription } from "./WebNavDrawerHeaderItemDescription";
/**
 * @hidden
 */
export let WebNavDrawerHeaderItemDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebNavDrawerHeaderItemDescriptionMetadata extends Base {
        static b(a) {
            if (WebNavDrawerHeaderItemDescriptionMetadata.a == null) {
                WebNavDrawerHeaderItemDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebNavDrawerHeaderItemDescriptionMetadata.c(WebNavDrawerHeaderItemDescriptionMetadata.a);
            }
            if (a.k(WebNavDrawerHeaderItemDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebNavDrawerHeaderItemDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:NavDrawerHeaderItem");
            a.item("__tagNameWC", "String:igc-nav-drawer-header-item");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        }
        static d(a) {
            WebNavDrawerHeaderItemDescriptionMetadata.b(a);
            a.ae("WebNavDrawerHeaderItem", () => new WebNavDrawerHeaderItemDescription());
            a.ad("WebNavDrawerHeaderItem", WebNavDrawerHeaderItemDescriptionMetadata.a);
        }
    }
    WebNavDrawerHeaderItemDescriptionMetadata.$t = /*@__PURE__*/ markType(WebNavDrawerHeaderItemDescriptionMetadata, 'WebNavDrawerHeaderItemDescriptionMetadata');
    WebNavDrawerHeaderItemDescriptionMetadata.a = null;
    return WebNavDrawerHeaderItemDescriptionMetadata;
})();
